# Neighborly Talk of the Town Plugin

This is a _Talk of the Town_ plugin designed to work with the Neighborly.
It modified implementations of data definitions and logic from the original
_Talk of the Town_.
